import os
import sys
import os.path as path
import argparse

import numpy as np
import igl
import polyscope as ps

import meshgen_tools

def main():

    parser = argparse.ArgumentParser()

    # Build arguments
    parser.add_argument('mesh', type=str, help='path to a mesh')

    # Parse arguments
    args = parser.parse_args()

    dump_frames = True

    ps.set_ground_plane_mode("shadow_only")
    ps.set_SSAA_factor(3)
    ps.init()

    if dump_frames:
        ps.set_view_from_json(
            """
    {"farClipRatio":20.0,"fov":45.0,"nearClipRatio":0.005,"projectionMode":"Perspective","viewMat":[0.490441143512726,-7.45058059692383e-09,-0.87147444486618,-0.319709986448288,-0.489276260137558,0.827520191669464,-0.275350689888,-0.689705371856689,0.721162974834442,0.561435282230377,0.405849188566208,-1.01671874523163,0.0,0.0,0.0,1.0],"windowHeight":846,"windowWidth":1512}
            """
        )

    # Load mesh from args
    # V, F = igl.read_triangle_mesh(args.mesh)
    # print(f"loaded mesh with {V.shape[0]} verts and {F.shape[0]} faces")
    V, F_flat, F_deg = meshgen_tools.load_mesh_poly_flat(args.mesh);
    F_tri = meshgen_tools.triangulate_polygons_flat_list(V, F_flat, F_deg)
    ps.register_surface_mesh("orig", V, F_tri, enabled=False);

    # Test the augmentation function

    if dump_frames:

        for i in range(100):

            opts = meshgen_tools.MeshAugmentorOptions()
            newV, newF_flat, newF_deg = meshgen_tools.augment_mesh_poly(V, F_flat, F_deg, opts)
            newF_tri = meshgen_tools.triangulate_polygons_flat_list(newV, newF_flat, newF_deg)

            ps.register_surface_mesh("augmented", newV, newF_tri, edge_width=1.0);
            # ps.show()
            ps.screenshot();

            igl.write_obj(f"mesh_{i:06d}.obj", newV, newF_tri)

    else:
        
        opts = meshgen_tools.MeshAugmentorOptions()
        newV, newF_flat, newF_deg = meshgen_tools.augment_mesh_poly(V, F_flat, F_deg, opts)
        newF_tri = meshgen_tools.triangulate_polygons_flat_list(newV, newF_flat, newF_deg)

        ps.register_surface_mesh("augmented", newV, newF_tri, edge_width=1.0);
        ps.show()


if __name__ == '__main__':
    main()
